@@ -4,8 +4,8 @@ The Snap7 Python library.
 import snap7.server as server
 import snap7.client as client
 import snap7.error as error
-import snap7.types as types
+import snap7.snap7types as types
 import snap7.common as common
 import snap7.util as util
 
-__version__ = '0.2.2'
+__version__ = '0.3'
