@@ -12,8 +12,8 @@ tcpport = 1102
 def mainloop():
     server = snap7.server.Server()
     size = 100
-    data = (snap7.types.wordlen_to_ctypes[snap7.types.S7WLByte] * size)()
-    server.register_area(snap7.types.srvAreaDB, 1, data)
+    data = (snap7.snap7types.wordlen_to_ctypes[snap7.snap7types.S7WLByte] * size)()
+    server.register_area(snap7.snap7types.srvAreaDB, 1, data)
 
     server.start(tcpport=tcpport)
     while True:
